About
=====

Contact
-------

There is a `mailing list`_ for questions.

NXT-Python repository maintainer is Nicolas Schodet, since 2021-11-06. You can
contact him on the mailing list.

You can use the `Github issues page`_ to report problems, but please use the
mailing list for questions.

.. _mailing list: https://lists.sr.ht/~ni/nxt-python
.. _Github issues page: https://github.com/schodet/nxt-python/issues


License
-------

NXT-Python is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/.
